@@ -1,6 +1,3 @@
-#! /usr/bin/env python3
-
-
 # import dependencies
 import logging
 import random
@@ -85,7 +82,7 @@ logging.basicConfig(filename=LOGFILE, filemode='a+', level=0, format='%(levelnam
 try:
     with open('/etc/os-release', 'r') as f:
         os_file = f.read()
-        regex = r'\sID="?(\w+)"?'
+        regex = r'\sID="?(\w+)"?\n'
         ID = re.search(regex, os_file).group()
         DISTNAME = 'ubuntu' if ID == 'ubuntu' else 'centos'
 except FileNotFoundError:
@@ -265,178 +262,69 @@ def check_passphrase(passphrase, passphrase_confirmation, passphrase_length):
             return s3cret
 
 
-#____________________________________
-def unwrap_vault_token(url, wrapping_token):
-    url = url + '/v1/sys/wrapping/unwrap'
-    headers = { "X-Vault-Token": wrapping_token }
-
-    response = requests.post(url, headers=headers, verify=False)
-    response.raise_for_status()
-    deserialized_response = json.loads(response.text)
-
-    try:
-        deserialized_response["auth"]["client_token"]
-    except KeyError:
-        raise Exception("[FATAL] Unable to unwrap vault token.")
-
-    return deserialized_response["auth"]["client_token"]
-
-
-#____________________________________
-def post_secret(url, path, token, key, value):
-    url = url + '/v1/secrets/data/' + path
-    headers = { "X-Vault-Token": token }
-    data = '{ "options": { "cas": 0 }, "data": { "'+key+'": "'+value+'"} }'
-
-    response = requests.post(url, headers=headers, data=data, verify=False)
-    response.raise_for_status()
-    deserialized_response = json.loads(response.text)
-
-    try:
-        deserialized_response["data"]
-    except KeyError:
-        raise Exception("[FATAL] Unable to write vault path.")
-
-    return deserialized_response
-
-
-#______________________________________
-def parse_response(response):
-    if not response["data"]["created_time"]:
-        raise Exception("No cretation time")
-
-    if response["data"]["destroyed"] != False:
-        raise Exception("Token already detroyed")
-
-    if response["data"]["version"] != 1:
-        raise Exception("Token not at 1st verion")
-
-    if response["data"]["deletion_time"] != "":
-        raise Exception("Token aready deleted")
-
-    return 0
-
-
-#______________________________________
-def revoke_token(url, token):
-    url = url + '/v1/auth/token/revoke-self'
-    headers = { "X-Vault-Token": token }
-    response = requests.post( url, headers=headers, verify=False )
-
-
-#______________________________________
-def write_secret_to_vault(vault_url, wrapping_token, secret_path, user_key, user_value):
-    # Check vault
-    r = requests.get(vault_url)
-    r.raise_for_status()
-
-    write_token = unwrap_vault_token(vault_url, wrapping_token)
-    response_output = post_secret(vault_url, secret_path, write_token, user_key, user_value)
-    parse_response(response_output)
-
-    revoke_token(vault_url, write_token)
-
 
 #____________________________________
 class device:
     
-    def __init__(self, name, cryptdev, mountpoint, filesystem):
-        self.name = name
+    def __init__(self, device_name, cryptdev, mountpoint, filesystem):
+        self.device_name = device_name
         self.cryptdev = cryptdev
         self.mountpoint = mountpoint
         self.filesystem = filesystem
     
-    # Setters
-    def set_name(self, name):
-        self.name = name
-    
-    def set_cryptdev(self, cryptdev):
-        self.cryptdev = cryptdev
-
-    def set_mountpoint(self, mountpoint):
-        self.mountoint = mountpoint
-
-    def set_filesystem(self, filesystem):
-        self.filesystem = filesystem
-
-    # Getters
-    def get_name(self):
-        return self.name
-
-    def get_cryptdev(self):
-        return self.cryptdev
-
-    def get_mountpoint(self):
-        return self.mountpoint
-
-    def get_filesystem(self):
-        return self.filesystem
-
-    # Check volume mounted on mountpoint and the device
     def check_vol(self):
-        logs('DEBUG', 'Checking storage volume.')
+        logging.debug('Checking storage volume.')
 
         if os.path.ismount(self.mountpoint):
             mounted_device, _, _ = run_command(f'df -P {self.mountpoint} | tail -1 | cut -d" " -f 1')
-            logs('DEBUG', f'Device name: {mounted_device}')
+            logging.debug(f'Device name: {mounted_device}')
 
         else:
-            if Path(self.device).is_block_device():
-                logs('DEBUG', f'External volume on {self.device}. Using it for encryption.')
+            if Path(self.device_name).is_block_device():
+                logging.debug(f'External volume on {self.device_name}. Using it for encryption.')
                 if not os.path.isdir(self.mountpoint):
-                    logs('DEBUG', f'Creating {self.mountpoint}')
+                    logging.debug(f'Creating {self.mountpoint}')
                     os.makedirs(self.mountpoint, exist_ok=True)
-                    logs('DEBUG', f'Device name: {self.device}')
-                    logs('DEBUG', f'Mountpoint: {self.mountpoint}')
+                    logging.debug(f'Device name: {self.device_name}')
+                    logging.debug(f'Mountpoint: {self.mountpoint}')
             else:
-                logs('ERROR', 'Device not mounted, exiting! Please check logfile:')
-                logs('ERROR', f'No device mounted to {self.mountpoint}')
+                logging.error('Device not mounted, exiting! Please check logfile:')
+                logging.error(f'No device mounted to {self.mountpoint}')
                 run_command('df -h', log_stderr_stdout=True)
                 return "unlock" # TODO MAIN SCRIPT: unlock and terminate process
     
-    # Check if the device is LUKS encrypted
     def is_encrypted(self):
-        logs('DEBUG', 'Checking if the volume is already encrypted.')
+        logging.debug('Checking if the volume is already encrypted.')
         devices, _, _ = run_command('lsblk -p -o NAME,FSTYPE')
-        if re.search(f'{self.device}\s+crypto_LUKS', devices):
-                logs('INFO', 'The volume is already encrypted')
+        if re.search(f'{self.device_name}\s+crypto_LUKS', devices):
+                logging.info('The volume is already encrypted')
                 return True
         else:
             return False
 
-    # Unmount device
     def umount_vol(self):
-        logs('INFO', 'Umounting device.')
+        logging.info('Umounting device.')
         run_command(f'umount {self.mountpoint}', log_stderr_stdout=True)
-        logs('INFO', f'{self.device} umounted, ready for encryption!')
+        logging.info(f'{self.device_name} umounted, ready for encryption!')
 
-    # Mount device
-    def mount_volume(self):
-        echo('INFO', 'Mounting encrypted device.')
-        logs('INFO', f'Mounting /dev/mapper/{self.cryptdev} to {self.mountpoint}')
-        run_command(f'mount /dev/mapper/{self.cryptdev} {self.mountpoint}', log_stderr_stdout=True)
-        run_command('df -Hv', log_stderr_stdout=True)
-
-    # cryptsetup functions
     def luksFormat(self, s3cret, cipher_algorithm, keysize, hash_algorithm):
-        return run_command(f'printf "{s3cret}\n" | cryptsetup -v --cipher {cipher_algorithm} --key-size {keysize} --hash {hash_algorithm} --iter-time 2000 --use-urandom luksFormat {self.device} --batch-mode')
+        return run_command(f'printf "{s3cret}\n" | cryptsetup -v --cipher {cipher_algorithm} --key-size {keysize} --hash {hash_algorithm} --iter-time 2000 --use-urandom luksFormat {self.device_name} --batch-mode')
 
     def luksHeaderBackup(self, luks_header_backup_dir, luks_header_backup_file):
-        return run_command(f'cryptsetup luksHeaderBackup --header-backup-file {luks_header_backup_dir}/{luks_header_backup_file} {self.device}')
+        return run_command(f'cryptsetup luksHeaderBackup --header-backup-file {luks_header_backup_dir}/{luks_header_backup_file} {self.device_name}')
 
     def luksOpen(self, s3cret):
-        return run_command(f'printf "{s3cret}\n" | cryptsetup luksOpen {self.device} {self.cryptdev}')
+        return run_command(f'printf "{s3cret}\n" | cryptsetup luksOpen {self.device_name} {self.cryptdev}')
 
-    # Setup the device
     def setup_device(self, vault_url, wrapping_token, secret_path, user_key, luks_header_backup_dir,
                     luks_header_backup_file, lock, LOCKFILE, cipher_algorithm, keysize, hash_algorithm,
                     passphrase=None, passphrase_confirmation=None, passphrase_length=None):
             echo('INFO', 'Start the encryption procedure.')
-            logs('INFO', f'Using {cipher_algorithm} algorithm to luksformat the volume.')
-            logs('DEBUG', 'Start cryptsetup')
-            info(self.device, cipher_algorithm, hash_algorithm, keysize, self.cryptdev, self.mountpoint, self.filesystem)
-            logs('DEBUG', 'Cryptsetup full command:')
-            logs('DEBUG', 'cryptsetup -v --cipher $cipher_algorithm --key-size $keysize --hash $hash_algorithm --iter-time 2000 --use-urandom --verify-passphrase luksFormat $device --batch-mode')
+            logging.info(f'Using {cipher_algorithm} algorithm to luksformat the volume.')
+            logging.debug('Start cryptsetup')
+            info(self.device_name, cipher_algorithm, hash_algorithm, keysize, self.cryptdev, self.mountpoint, self.filesystem)
+            logging.debug('Cryptsetup full command:')
+            logging.debug('cryptsetup -v --cipher $cipher_algorithm --key-size $keysize --hash $hash_algorithm --iter-time 2000 --use-urandom --verify-passphrase luksFormat $device --batch-mode')
 
             s3cret = check_passphrase(passphrase, passphrase_confirmation, passphrase_length)
             if s3cret == False:
@@ -460,12 +348,11 @@ class device:
                 # 3 out of memory
                 # 4 wrong device specified
                 # 5 device already exists or device is busy.
-                logs('ERROR', f'Command cryptsetup failed with exit code {luksHeaderBackup_ec}! Mounting {self.device} to {self.mountpoint} and exiting.')
+                logging.error(f'Command cryptsetup failed with exit code {luksHeaderBackup_ec}! Mounting {self.device_name} to {self.mountpoint} and exiting.')
                 if luksHeaderBackup_ec == 2:
                     echo('ERROR', 'Bad passphrase. Please try again.')
                 return False # TODO MAIN SCRIPT: unlock and exit
     
-    # Open LUKS encrypted device
     def open_device(self, s3cret):
         echo('INFO', 'Open LUKS volume')
         if not Path(f'/dev/mapper{self.cryptdev}').is_block_device():
@@ -477,20 +364,18 @@ class device:
                     return False # TODO MAIN SCRIPT: unlock and exit
                 else:
                     echo('ERROR', f'Crypt device already exists! Please check logs: {LOGFILE}')
-                    logs('ERROR', 'Unable to luksOpen device.')
-                    logs('ERROR', f'/dev/mapper/{self.cryptdev} already exists.')
-                    logs('ERROR', f'Mounting {self.device} to {self.mountpoint} again.')
-                    run_command(f'mount {self.device} {self.mountpoint}', log_stderr_stdout=True)
+                    logging.error('Unable to luksOpen device.')
+                    logging.error(f'/dev/mapper/{self.cryptdev} already exists.')
+                    logging.error(f'Mounting {self.device_name} to {self.mountpoint} again.')
+                    run_command(f'mount {self.device_name} {self.mountpoint}', log_stderr_stdout=True)
                     return False # TODO MAIN SCRIPT: unlock and exit
     
-    # Return encryption status
     def encryption_status(self):
-        logs('INFO', f'Check {self.cryptdev} status with cryptsetup status')
+        logging.info(f'Check {self.cryptdev} status with cryptsetup status')
         run_command(f'cryptsetup -v status {self.cryptdev}', log_stderr_stdout=True)
     
-    # Create cryptdev ini file
     def create_cryptdev_ini_file(self, now, cipher_algorithm, has_algorithm, keysize, luksUUID, luks_header_backup_dir, luks_header_backup_file):
-        luksUUID, _, _ = run_command(f'cryptsetup luksUUID {self.device}')
+        luksUUID, _, _ = run_command(f'cryptsetup luksUUID {self.device_name}')
 
         with open(luks_cryptdev_file, 'w') as f:
             f.write('# This file has been generated using fast_luks.sh script\n')
@@ -499,13 +384,13 @@ class device:
             f.write('# LUKS provides a UUID (Universally Unique Identifier) for each device.\n')
             f.write('# This, unlike the device name (eg: /dev/vdb), is guaranteed to remain constant\n')
             f.write('# as long as the LUKS header remains intact.\n')
-            f.write(f'# LUKS header information for {self.device}\n')
+            f.write(f'# LUKS header information for {self.device_name}\n')
             f.write(f'# luks-{now}\n')
             f.write(f'[luks]\n')
             f.write(f'cipher_algorithm = {cipher_algorithm}\n')
             f.write(f'hash_algorithm = {hash_algorithm}\n')
             f.write(f'keysize = {keysize}\n')
-            f.write(f'device = {self.device}\n')
+            f.write(f'device = {self.device_name}\n')
             f.write(f'uuid = {luksUUID}\n')
             f.write(f'cryptdev = {self.cryptdev}\n')
             f.write(f'mapper = /dev/mapper/{self.cryptdev}\n')
@@ -514,26 +399,30 @@ class device:
             f.write(f'header_path = {luks_header_backup_dir}/{luks_header_backup_file}\n')
         
         run_command(f'dmsetup info /dev/mapper/{self.cryptdev}', log_stderr_stdout=True)
-        run_command(f'cryptsetup luksDump {self.device}', log_stderr_stdout=True)
+        run_command(f'cryptsetup luksDump {self.device_name}', log_stderr_stdout=True)
 
-    # Fill the volume with zeros
     def wipe_data(self):
         echo('INFO', 'Paranoid mode selected. Wiping disk')
-        logs('INFO', 'Wiping disk data by overwriting the entire drive with random data.')
-        logs('INFO', 'This might take time depending on the size & your machine!')
+        logging.info('Wiping disk data by overwriting the entire drive with random data.')
+        logging.info('This might take time depending on the size & your machine!')
         
         run_command(f'dd if=/dev/zero of=/dev/mapper/{self.cryptdev} bs=1M status=progress')
         
-        logs('INFO', f'Block file /dev/mapper/{self.cryptdev} created.')
-        logs('INFO', 'Wiping done.')
+        logging.info(f'Block file /dev/mapper/{self.cryptdev} created.')
+        logging.info('Wiping done.')
 
-    # Make device filesystem
     def create_fs(self):
         echo('INFO', 'Creating filesystem.')
-        logs('INFO', f'Creating {self.filesystem} filesystem on /dev/mapper/{self.cryptdev}')
+        logging.info(f'Creating {self.filesystem} filesystem on /dev/mapper/{self.cryptdev}')
         _, _, mkfs_ec = run_command(f'mkfs -t {self.filesystem} /dev/mapper/{self.cryptdev}', log_stderr_stdout=True)
         if mkfs_ec != 0:
             echo('ERROR', f'While creating {self.filesystem} filesystem. Please check logs.')
             echo('ERROR', 'Command mkfs failed!')
-            return False # TODO MAIN SCRIPT: unlock and exit    
+            return False # TODO MAIN SCRIPT: unlock and exit
+    
+    def mount_volume(self):
+        echo('INFO', 'Mounting encrypted device.')
+        logging.info(f'Mounting /dev/mapper/{self.cryptdev} to {self.mountpoint}')
+        run_command(f'mount /dev/mapper/{self.cryptdev} {self.mountpoint}', log_stderr_stdout=True)
+        run_command('df -Hv', log_stderr_stdout=True)
 
